% linlogspace - joined linear/log map
%
% linlogspace ::
%     F0:nonneg ~'starting of linear ramp',
%     F1:nonneg ~'crossover from linear to log',
%     N1:natural ~'number of steps in linear part',
%     R1:nonneg  ~'ratio of increase in log part',
%     N2:nonneg  ~'number of steps in log part'
% -> [[1,1+N1+N2]->nonneg].

function f=linlogspace(f0,f1,n1,r1,n2), f = [ linspace(f0, f1, n1), f1*r1.^(1:n2) ]; end
